# Ververser Example 2: Game Class

Ververser supports the functions typically found in games: _init_, _update_ and _draw_.
Often, state is shared between these function calls, and this state is commonly encapsulated in a class. 
This example illustrates how such a class can be defined and called from the ververser entrypoints in the main script. 
